@@ -38,7 +38,7 @@ from sure.magic import is_cpython, patchable_builtin
 from sure.registry import context as _registry
 
 
-version = '1.1.4'
+version = '1.1.5'
 
 
 not_here_error = \
@@ -572,7 +572,7 @@ class AssertionBuilder(object):
         try:
             comparison = DeepComparison(self.obj, what).compare()
             error = False
-        except AssertionError as e:
+        except AssertionError, e:
             error = e
             comparison = None
 
